gluetool - A tool for gluing together one-file python modules in a sequential command-line pipeline
---------------------------------------------------------------------------------------------------

``gluetool`` is a command line centric generic framework useable for glueing modules into pipeline


.. image:: https://travis-ci.org/gluetool/gluetool.svg?branch=master
    :target: https://travis-ci.org/gluetool/gluetool

.. image:: https://codecov.io/gh/gluetool/gluetool/branch/master/graph/badge.svg
     :target: https://codecov.io/gh/gluetool/gluetool
     :alt: Code coverage

.. image:: https://requires.io/github/gluetool/gluetool/requirements.svg?branch=master
     :target: https://requires.io/github/gluetool/gluetool/requirements/?branch=master
     :alt: Requirements Status

.. image:: https://readthedocs.org/projects/gluetool/badge/?version=latest
     :target: http://gluetool.readthedocs.io/en/latest/?badge=latest
     :alt: Documentation Status


Documentation
-------------

For more information see documentation:

http://gluetool.readthedocs.io/
